@@ -18,28 +18,39 @@
 
 import os
 import sys
+import appdirs
 try:
     import configparser
 except ImportError:
     import ConfigParser as configparser
-import appdirs
 from .exceptions import GameNotExistError
 
 
 class Config(object):
+    """Config holds getters and setters that translate to calls to a
+    configparser.
 
-    def __init__(self, game, author, program_name, filename=None):
+    :ivar game: Short identifier of game.
+    :type game: str.
+    :ivar fileobj: File object that is read from/written to.
+    :type fileobj: TextIOWrapper.
+    :ivar refresh: Toggle for whether setters write to ``fileobj``.
+    :type refresh: bool.
+    """
+
+    def __init__(self, game, fileobj, refresh=True):
+        """Create a Config instance.
+
+        :param game: Short identifier of game.
+        :type game: str.
+        :param fileobj: File object.
+        :type fileobj: TextIOWrapper.
+        :param refresh: Toggle for whether setters write to ``fileobj``.
+        :type refresh: bool.
+        """
         self.game = game
-        self.author = author
-        self.program_name = program_name
-        # Sets filename to default path if none is given.
-        if filename is None:
-            self.filename = os.path.join(appdirs.user_data_dir(program_name,
-                                                               author),
-                                         "pyparadox.conf")
-        # Changes filename to custom full file path if one is supplied.
-        else:
-            self.filename = filename
+        self.fileobj = fileobj
+        self.refresh = refresh
 
         if self.game == "eu4":
             self.full_game = "Europa Universalis IV"
@@ -48,31 +59,15 @@ class Config(object):
         else:
             raise GameNotExistError()
 
-        self.config = configparser.ConfigParser()
-        self.create_config()
-        self.config.read(self.filename)
-        if not self.config.has_section(self.game):
+        self._config = configparser.ConfigParser()
+        self._config.readfp(self.fileobj)
+        if not self._config.has_section(self.game):
             self.set_default_layout()
 
-    def create_config(self):
-        """Creates an empty config file if none exists. Does nothing
-        otherwise.
+    def set_default_layout(self):
+        """Set a game entry in ``_config`` to some default values dependent on
+        platform.
         """
-        try:
-            os.makedirs(os.path.dirname(self.filename))
-        except:
-            if os.path.isdir(os.path.dirname(self.filename)):
-                pass
-            else:
-                # This isn't supposed to happen.
-                raise Exception("please report: ponies")
-        try:
-            open(self.filename, 'a').close()
-        except IOError as err:
-            raise err
-
-    def set_default_layout(self, refresh=True):
-        """Creates a default game entry."""
         # No mods or DLCs selected by default.
         excluded_dlcs = ""
         mods = ""
@@ -116,74 +111,110 @@ class Config(object):
                                     self.full_game,
                                     "mod")
 
-        self.config.add_section(self.game)
-        self.config.set(self.game, "game_path", game_path)
-        self.config.set(self.game, "mod_path", mod_path)
-        self.config.set(self.game, "binary", binary)
-        self.config.set(self.game, "excluded_dlcs", excluded_dlcs)
-        self.config.set(self.game, "mods", mods)
+        try:
+            self._config.add_section(self.game)
+        except configparser.DuplicateSectionError:
+            pass
 
-        if refresh:
+        self.game_path = game_path
+        self.mod_path = mod_path
+        self.binary = binary
+        self.excluded_dlcs = excluded_dlcs
+        self.mods = mods
+
+        if self.refresh:
             self.refresh_config_file()
 
     def refresh_config_file(self):
-        with open(self.filename, 'w') as configfile:
-            self.config.write(configfile)
+        """Write the state of ``_config`` to ``fileobj``."""
+        self.fileobj.seek(0)
+        self.fileobj.truncate()
+        self._config.write(self.fileobj)
 
     @property
     def game_path(self):
-        return self.config.get(self.game, "game_path")
+        """Absolute path towards the root of the game directory.
+
+        :getter: Read value from ``_config``.
+        :setter: Write value to ``_config``.
+        :type: str.
+        """
+        return self._config.get(self.game, "game_path")
 
     @game_path.setter
-    def game_path(self, path, refresh=True):
-        self.config.set(self.game, "game_path", path)
-        if refresh:
+    def game_path(self, path):
+        self._config.set(self.game, "game_path", path)
+        if self.refresh:
             self.refresh_config_file()
 
     @property
     def mod_path(self):
-        return self.config.get(self.game, "mod_path")
+        """Absolute path towards the mod directory.
+
+        :getter: Read value from ``_config``.
+        :setter: Write value to ``_config``.
+        :type: str.
+        """
+        return self._config.get(self.game, "mod_path")
 
     @mod_path.setter
-    def mod_path(self, path, refresh=True):
-        self.config.set(self.game, "mod_path", path)
-        if refresh:
+    def mod_path(self, path):
+        self._config.set(self.game, "mod_path", path)
+        if self.refresh:
             self.refresh_config_file()
 
     @property
     def binary(self):
-        return self.config.get(self.game, "binary")
+        """Basename of the binary file.
+
+        :getter: Read value from ``_config``.
+        :setter: Write value to ``_config``.
+        :type: str.
+        """
+        return self._config.get(self.game, "binary")
 
     @binary.setter
-    def binary(self, binary, refresh=True):
-        self.config.set(self.game, "binary", binary)
-        if refresh:
+    def binary(self, binary):
+        self._config.set(self.game, "binary", binary)
+        if self.refresh:
             self.refresh_config_file()
 
     @property
     def excluded_dlcs(self):
-        dlcs = self.config.get(self.game, "excluded_dlcs").split(',')
+        """List of basenames of ".dlc" files.
+
+        :getter: Read value from ``_config``.
+        :setter: Write value to ``_config``.
+        :type: list.
+        """
+        dlcs = self._config.get(self.game, "excluded_dlcs").split(',')
         if len(dlcs) == 1 and dlcs[0] == "":
             return []
         else:
             return dlcs
 
     @excluded_dlcs.setter
-    def excluded_dlcs(self, dlcs, refresh=True):
-        self.config.set(self.game, "excluded_dlcs", ','.join(dlcs))
-        if refresh:
+    def excluded_dlcs(self, dlcs):
+        self._config.set(self.game, "excluded_dlcs", ','.join(dlcs))
+        if self.refresh:
             self.refresh_config_file()
 
     @property
     def mods(self):
-        mods = self.config.get(self.game, "mods").split(',')
+        """List of basenames of ".mod" files.
+
+        :getter: Read value from ``_config``.
+        :setter: Write value to ``_config``.
+        :type: list.
+        """
+        mods = self._config.get(self.game, "mods").split(',')
         if len(mods) == 1 and mods[0] == "":
             return []
         else:
             return mods
 
     @mods.setter
-    def mods(self, mods, refresh=True):
-        self.config.set(self.game, "mods", ','.join(mods))
-        if refresh:
+    def mods(self, mods):
+        self._config.set(self.game, "mods", ','.join(mods))
+        if self.refresh:
             self.refresh_config_file()
