@@ -17,16 +17,33 @@
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 import os
-from ..exceptions import PySideImportError
-try:
-    from PySide import QtGui
-    from PySide.QtCore import Slot
-except ImportError:
-    raise PySideImportError
+from ..Qt import QtCore, QtGui
 
 
 class ConfigDlg(QtGui.QDialog):
-    """Dialog interface that allows editing of the configuration file."""
+    """Dialog interface that allows editing of the configuration file.
+
+    :ivar game_path_lbl: Label that describes ``game_path_edit``.
+    :type game_path_lbl: QLabel.
+    :ivar game_path_edit: LinEdit that contains path to the game folder.
+    :type game_path_edit: QLineEdit.
+    :ivar game_path_btn: Button that opens a file dialog.
+    :type game_path_btn: QPushButton.
+    :ivar mod_path_lbl: Label that describes ``mod_path_edit``.
+    :type mod_path_lbl: QLabel.
+    :ivar mod_path_edit: LinEdit that contains path to the mod folder.
+    :type mod_path_edit: QLineEdit.
+    :ivar mod_path_btn: Button that opens a file dialog.
+    :type mod_path_btn: QPushButton.
+    :ivar binary_lbl: Label that describes ``binary_edit``.
+    :type binary_lbl: QLabel.
+    :ivar binary_edit: LineEdit that contains the name of the game binary.
+    :type binary_edit: QLineEdit.
+    :ivar binary_btn: Button that opens a file dialog.
+    :type binary_btn: QPushButton.
+    :ivar button_box: Widget that contains buttons that accept or reject.
+    :type button_box: QDialogButtonBox.
+    """
 
     def __init__(self, parent=None):
         super(ConfigDlg, self).__init__()
@@ -85,7 +102,7 @@ class ConfigDlg(QtGui.QDialog):
         self.setLayout(layout)
         self.setWindowTitle(self.tr("Configure"))
 
-    @Slot()
+    @QtCore.Slot()
     def fill_game_path_edit(self):
         old_path = self.game_path_edit.text()
         if not os.path.isdir(old_path):
@@ -96,7 +113,7 @@ class ConfigDlg(QtGui.QDialog):
         if path:
             self.game_path_edit.setText(path)
 
-    @Slot()
+    @QtCore.Slot()
     def fill_mod_path_edit(self):
         old_path = self.mod_path_edit.text()
         if not os.path.isdir(old_path):
@@ -107,7 +124,7 @@ class ConfigDlg(QtGui.QDialog):
         if path:
             self.mod_path_edit.setText(path)
 
-    @Slot()
+    @QtCore.Slot()
     def fill_binary_edit(self):
         game_path = self.game_path_edit.text()
         if not os.path.isdir(game_path):
