@@ -17,28 +17,58 @@
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 import os
+import pkg_resources
 from ..command import make_command, execute_command
-from ..exceptions import PySideImportError
 from ..find import find_dlcs, find_mods
 from ..Dlc import Dlc
 from ..Mod import Mod
+from ..Qt import QtCore, QtGui
 from .ConfigDlg import ConfigDlg
 from .PluginListModel import PluginListModel
-try:
-    from PySide import QtGui
-    from PySide.QtCore import Slot
-except ImportError:
-    raise PySideImportError
+from .. import __name__ as package_name
 
 
 class MainWindow(QtGui.QMainWindow):
-    """Main window for the application."""
+    """Main window for the application.
 
-    def __init__(self, game, config, parent=None):
+    :ivar central_widget: Widget that contains all widgets.
+    :type central_widget: QWidget.
+    :ivar game_lbl: Label that contains a picture of the game.
+    :type game_lbl: QLabel.
+    :ivar mods_lbl: Label that describes ``mods_list``.
+    :type mods_lbl: QLabel.
+    :ivar mods_list: View for a list of checkable mods.
+    :type mods_list: QListView.
+    :ivar mods_model: Model that holds a list of mods.
+    :type mods_model: PluginListModel.
+    :ivar dlcs_lbl: Label that describes ``dlcs_list``.
+    :type dlcs_lbl: QLabel.
+    :ivar dlcs_model: Model that holds a list of DLCs.
+    :type dlcs_model: PluginListModel.
+    :ivar dlcs_list: View for a list of checkable DLCs.
+    :ivar config_btn: Button that leads to a configuration dialog.
+    :type config_btn: QPushButton.
+    :ivar run_btn: Button that starts the game.
+    :type run_btn: QPushButton.
+    :ivar config: Object that stores application settings.
+    :type config: Config.
+    """
+
+    def __init__(self, config, parent=None):
+        """Initialise the MainWindow.__class__
+
+        :param config: Object that stores application settings.
+        :type config: Config.
+        :param parent: Parent QWidget.
+        :type parent: QWidget.
+        """
         super(MainWindow, self).__init__(parent)
+        self.config = config
+
         self.init_ui()
 
-        self.config = config
+        self.mods_model = None
+        self.dlcs_model = None
 
         self.fill_dlcs()
         self.fill_mods()
@@ -49,10 +79,20 @@ class MainWindow(QtGui.QMainWindow):
         self.run_btn.clicked.connect(self.run_game)
 
     def init_ui(self):
-        """Initialises all (empty) UI elements."""
+        """Initialise all (empty) UI elements."""
         self.central_widget = QtGui.QWidget(self)
         self.setCentralWidget(self.central_widget)
 
+        picture_layout = QtGui.QHBoxLayout()
+        picture_layout.addStretch()
+        self.game_lbl = QtGui.QLabel()
+        # Gets file path to respective game from pkg_resources.  Sets it as the
+        # pixmap of a label.
+        self.game_lbl.setPixmap(pkg_resources.resource_filename(package_name,
+                                "resources/{}.png".format(self.config.game)))
+        picture_layout.addWidget(self.game_lbl)
+        picture_layout.addStretch()
+
         mods_layout = QtGui.QVBoxLayout()
         self.mods_lbl = QtGui.QLabel(self.tr("&Mods:"))
         self.mods_list = QtGui.QListView()
@@ -79,7 +119,7 @@ class MainWindow(QtGui.QMainWindow):
         buttons_layout.addWidget(self.run_btn)
 
         layout = QtGui.QVBoxLayout()
-        # layout.addWidget(picture_of_game)
+        layout.addLayout(picture_layout)
         layout.addLayout(plugins_layout)
         layout.addLayout(buttons_layout)
 
@@ -87,8 +127,8 @@ class MainWindow(QtGui.QMainWindow):
         self.setWindowTitle(QtGui.QApplication.applicationName())
 
     def fill_dlcs(self):
-        """Fills the DLC ListView with found DLCs from the game folder and
-        unselects DLCs based on PyParadox's configuration file.
+        """Fill the DLC ListView with found DLCs from the game folder and
+        unselect DLCs based on PyParadox's configuration file.
         """
         dlcs = []
         # Find all DLCs inside the DLC folder.
@@ -112,8 +152,8 @@ class MainWindow(QtGui.QMainWindow):
         self.dlcs_list.setModel(self.dlcs_model)
 
     def fill_mods(self):
-        """Fills the mods ListView with found mods from the mod folder and
-        unselects mods based on PyParadox's configuration file.
+        """Fill the mods ListView with found mods from the mod folder and
+        unselect mods based on PyParadox's configuration file.
         """
         mods = []
         # Find all mods inside the mod folder.
@@ -135,8 +175,12 @@ class MainWindow(QtGui.QMainWindow):
         self.mods_model = PluginListModel(mods)
         self.mods_list.setModel(self.mods_model)
 
-    @Slot()
+    @QtCore.Slot()
     def show_config_dlg(self):
+        """Create a dumb ``ConfigDlg``, write data to it to set it up, then
+        retrieve its data and push it to ``config`` if it shut down
+        affirmatively.
+        """
         config_dlg = ConfigDlg()
         config_dlg.game_path_edit.setText(self.config.game_path)
         config_dlg.mod_path_edit.setText(self.config.mod_path)
@@ -148,8 +192,14 @@ class MainWindow(QtGui.QMainWindow):
             self.fill_dlcs()
             self.fill_mods()
 
-    @Slot()
+    @QtCore.Slot()
     def run_game(self):
+        """Extract data from ``mods_model`` and ``dlcs_model`` and write them
+        to ``config``.  Use all data from ``config`` to create a command and
+        try to execute it.  Assign the resulting process to the running
+        ``QApplication`` and shut down.  If the process couldn't start, give
+        a warning message.
+        """
         excluded_dlcs = [dlc.filename for dlc in self.dlcs_model.plugins if not
                          dlc.enabled]
         mods = [mod.filename for mod in self.mods_model.plugins if mod.enabled]
@@ -160,11 +210,15 @@ class MainWindow(QtGui.QMainWindow):
         command = make_command(self.config.game_path, self.config.binary,
                                self.config.excluded_dlcs, self.config.mods)
         try:
-            # Sets process to a variable inside the QApplication. This
+            # Set process to a variable inside the QApplication.  This
             # variable can be accessed after the QMainWindow quits.
             QtGui.QApplication.process = execute_command(command)
             self.close()
         except OSError:
-            QtGui.QMessageBox.warning(self,
-                                      self.tr("Error"),
-                                      self.tr("Game could not launch."))
+            msg_box = QtGui.QMessageBox(QtGui.QMessageBox.Warning,
+                                        self.tr("Error"),
+                                        self.tr("Game could not launch."))
+            msg_box.setDetailedText(" ".join(command))
+            msg_box.setStandardButtons(QtGui.QMessageBox.Ok)
+            msg_box.setDefaultButton(QtGui.QMessageBox.Ok)
+            msg_box.exec_()
